@@ -96,13 +96,16 @@ class IndexList(object):
             'allocated': self.filter_allocated,
             'closed': self.filter_closed,
             'count': self.filter_by_count,
+            'empty': self.filter_empty,
             'forcemerged': self.filter_forceMerged,
+            'ilm': self.filter_ilm,
             'kibana': self.filter_kibana,
             'none': self.filter_none,
             'opened': self.filter_opened,
             'period': self.filter_period,
             'pattern': self.filter_by_regex,
             'space': self.filter_by_space,
+            'shards': self.filter_by_shards,
         }
         return methods[ft]
 
@@ -252,7 +255,7 @@ class IndexList(object):
                 if err.status_code == 413:
                     self.loggit.debug('Huge Payload 413 Error - Trying to get information with multiple requests')
                     working_list = {}
-                    working_list.update(self._bulk_queries(l, self._get_indices_segments))  
+                    working_list.update(self._bulk_queries(l, self._get_indices_segments))
 
             if working_list:
                 for index in list(working_list.keys()):
@@ -394,14 +397,17 @@ class IndexList(object):
                     ' metadata'.format(index, self.age_keyfield)
                 )
                 self.__excludify(True, True, index, msg)
-
+        # Sort alphabetically prior to age sort to keep sorting consistent
+        temp_tuple = (
+            sorted(temp.items(), key=lambda k: k[0], reverse=reverse)
+        )
         # If reverse is True, this will sort so the youngest indices are first.
         # However, if you want oldest first, set reverse to False.
         # Effectively, this should set us up to act on everything older than
         # meets the other set criteria.
         # It starts as a tuple, but then becomes a list.
         sorted_tuple = (
-            sorted(temp.items(), key=lambda k: k[1], reverse=reverse)
+            sorted(temp_tuple, key=lambda k: k[1], reverse=reverse)
         )
         return [x[0] for x in sorted_tuple]
 
@@ -988,6 +994,55 @@ class IndexList(object):
                 self.__excludify(condition, exclude, index, msg)
                 idx += 1
 
+    def filter_by_shards(self, number_of_shards=None, shard_filter_behavior='greater_than', exclude=False):
+        """
+        Match `indices` with a given shard count.
+
+        Selects all indices with a shard count 'greater_than' number_of_shards by default.
+        Use shard_filter_behavior to select indices with shard count 'greater_than', 'greater_than_or_equal', 
+        'less_than', 'less_than_or_equal', or 'equal' to number_of_shards.
+
+        :arg number_of_shards: shard threshold 
+        :arg shard_filter_behavior: Do you want to filter on greater_than, greater_than_or_equal, less_than, 
+            less_than_or_equal, or equal?
+        :arg exclude: If `exclude` is `True`, this filter will remove matching
+            indices from `indices`. If `exclude` is `False`, then only matching
+            indices will be kept in `indices`.
+            Default is `False`
+        """
+        self.loggit.debug("Filtering indices by number of shards")
+        if not number_of_shards:
+            raise exceptions.MissingArgument('No value for "number_of_shards" provided')
+
+        if shard_filter_behavior not in ['greater_than', 'less_than', 'greater_than_or_equal', 'less_than_or_equal', 'equal']:
+            raise ValueError(
+                'Invalid value for "shard_filter_behavior": {0}'.format(
+                    shard_filter_behavior)
+            )
+
+        if number_of_shards < 1 or (shard_filter_behavior == 'less_than' and number_of_shards == 1):
+            raise ValueError(
+                'Unacceptable value: {0} -- "number_of_shards" cannot be less than 1. A valid index '
+                'will have at least one shard.'.format(number_of_shards)
+            )
+
+        self.empty_list_check()
+        for index in self.working_list():
+            self.loggit.debug('Filter by number of shards: Index: {0}'.format(index))
+
+            if shard_filter_behavior == 'greater_than':
+                condition = int(self.index_info[index]['number_of_shards']) > number_of_shards 
+            elif shard_filter_behavior == 'less_than':
+                condition = int(self.index_info[index]['number_of_shards']) < number_of_shards 
+            elif shard_filter_behavior == 'greater_than_or_equal':
+                condition = int(self.index_info[index]['number_of_shards']) >= number_of_shards 
+            elif shard_filter_behavior == 'less_than_or_equal':
+                condition = int(self.index_info[index]['number_of_shards']) <= number_of_shards 
+            else:
+                condition = int(self.index_info[index]['number_of_shards']) == number_of_shards 
+
+            self.__excludify(condition, exclude, index)
+
     def filter_period(
         self, period_type='relative', source='name', range_from=None, range_to=None,
         date_from=None, date_to=None, date_from_format=None, date_to_format=None,
@@ -1109,6 +1164,29 @@ class IndexList(object):
                     'Removing from list.'.format(index))
                 self.indices.remove(index)
 
+    def filter_ilm(self, exclude=True):
+        """
+        Match indices that have the setting `index.lifecycle.name`
+
+        :arg exclude: If `exclude` is `True`, this filter will remove matching
+            indices from `indices`. If `exclude` is `False`, then only matching
+            indices will be kept in `indices`.
+            Default is `True`
+        """
+        self.loggit.debug('Filtering indices with index.lifecycle.name')
+        index_lists = utils.chunk_index_list(self.indices)
+        for l in index_lists:
+            working_list = self.client.indices.get_settings(index=utils.to_csv(l))
+            if working_list:
+                for index in list(working_list.keys()):
+                    try:
+                        has_ilm = 'name' in working_list[index]['settings']['index']['lifecycle']
+                        msg = '{0} has index.lifecycle.name {1}'.format(index, working_list[index]['settings']['index']['lifecycle']['name'])
+                    except KeyError:
+                        has_ilm = False
+                        msg = 'index.lifecycle.name is not set for index {0}'.format(index)
+                    self.__excludify(has_ilm, exclude, index, msg)
+
     def iterate_filters(self, filter_dict):
         """
         Iterate over the filters defined in `config` and execute them.
